unit Prtsetup;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Printsel, Buttons, ExtCtrls;

type
  TdlgPrinterSetup = class(TForm)
    prtDef: TPrinterDefinition;
    chkPrinterDefault: TCheckBox;
    Label1: TLabel;
    cmbPaperSizes: TComboBox;
    Label2: TLabel;
    cmbBinSource: TComboBox;
    Label3: TLabel;
    chkPaperSizeDefault: TCheckBox;
    chkBinSourceDefault: TCheckBox;
    btnSave: TBitBtn;
    btnCancel: TBitBtn;
    btnExit: TBitBtn;
    cmbPrintQuality: TComboBox;
    Label4: TLabel;
    chkPrintQualityDefault: TCheckBox;
    rbnPortrait: TRadioButton;
    rbnLandscape: TRadioButton;
    Image1: TImage;
    Bevel1: TBevel;
    edtCopies: TEdit;
    Label5: TLabel;
    procedure prtDefBinChange(Sender: TObject);
    procedure cmbPaperSizesChange(Sender: TObject);
    procedure btnCancelClick(Sender: TObject);
    procedure btnSaveClick(Sender: TObject);
    procedure cmbBinSourceChange(Sender: TObject);
    procedure cmbPrintQualityChange(Sender: TObject);
    procedure chkPrinterDefaultClick(Sender: TObject);
    procedure chkPaperSizeDefaultClick(Sender: TObject);
    procedure chkBinSourceDefaultClick(Sender: TObject);
    procedure chkPrintQualityDefaultClick(Sender: TObject);
    procedure rbnPortraitClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
    procedure edtCopiesKeyPress(Sender: TObject; var Key: Char);
    procedure edtCopiesChange(Sender: TObject);
  private
    Changed: boolean;
    procedure CheckButtons;
  public
    { Public declarations }
  end;

var
  dlgPrinterSetup: TdlgPrinterSetup;

procedure SetupPrinter(const Section: string);
procedure SelectPrinterConfiguration(const Section: string);

implementation

{$R *.DFM}

procedure SetupPrinter(const Section: string);
begin
  with dlgPrinterSetup do
    begin
      prtDef.Profile:=Section;
      if Section<>'' then prtDef.ReadProfile;
      ShowModal;
    end;
end;

procedure SelectPrinterConfiguration(const Section: string);
begin
  with dlgPrinterSetup do
    begin
      prtDef.Profile:=Section;
      if Section<>'' then prtDef.ReadProfile;
    end;
end;

procedure TdlgPrinterSetup.CheckButtons;
begin
  btnSave.Enabled:=Changed and (prtDef.Profile<>'');
  btnCancel.Enabled:=btnSave.Enabled;
  btnExit.Enabled:=not btnSave.Enabled;
  chkPrinterDefault.Checked:=DefaultPrinter in prtDef.UseWinDefaults;
  chkPaperSizeDefault.Checked:=DefaultPaperSize in prtDef.UseWinDefaults;
  chkBinSourceDefault.Checked:=DefaultBin in prtDef.UseWinDefaults;
  chkPrintQualityDefault.Checked:=DefaultPrintQuality in prtDef.UseWinDefaults;
  if rbnPortrait.Checked<>(prtDef.PrinterSettings.Orientation=Portrait) then
     rbnPortrait.Checked:=not rbnPortrait.Checked;
  prtDef.Enabled:=not chkPrinterDefault.Checked;
  cmbPaperSizes.Enabled:=not chkPaperSizeDefault.Checked;
  cmbBinSource.Enabled:=not chkBinSourceDefault.Checked;
  cmbPrintQuality.Enabled:=not chkPrintQualityDefault.Checked;
end;

procedure TdlgPrinterSetup.prtDefBinChange(Sender: TObject);
begin
  Changed:=true;
  CheckButtons;
end;

procedure TdlgPrinterSetup.cmbPaperSizesChange(Sender: TObject);
begin
  prtDef.PrinterSettings.PaperSize:=cmbPaperSizes.Text;
end;

procedure TdlgPrinterSetup.cmbBinSourceChange(Sender: TObject);
begin
  prtDef.PrinterSettings.BinSource:=cmbBinSource.Text;
end;

procedure TdlgPrinterSetup.cmbPrintQualityChange(Sender: TObject);
begin
  prtDef.SetPrintQuality(cmbPrintQuality.Text);
  Changed:=true;
  CheckButtons;
end;

procedure TdlgPrinterSetup.btnCancelClick(Sender: TObject);
begin
  prtDef.ReadProfile;
  Changed:=false;
  CheckButtons;
end;

procedure TdlgPrinterSetup.btnSaveClick(Sender: TObject);
begin
  prtDef.PrinterSettings.Copies:=StrToInt(edtCopies.Text);
  prtDef.StoreProfile;
  Changed:=false;
  CheckButtons;
end;

procedure TdlgPrinterSetup.chkPrinterDefaultClick(Sender: TObject);
begin
  if chkPrinterDefault.Checked then
    prtDef.UseWinDefaults:=prtDef.UseWinDefaults+[DefaultPrinter]
  else
    prtDef.UseWinDefaults:=prtDef.UseWinDefaults-[DefaultPrinter];
  CheckButtons;
end;

procedure TdlgPrinterSetup.chkPaperSizeDefaultClick(Sender: TObject);
begin
  if chkPaperSizeDefault.Checked then
    prtDef.UseWinDefaults:=prtDef.UseWinDefaults+[DefaultPaperSize]
  else
    prtDef.UseWinDefaults:=prtDef.UseWinDefaults-[DefaultPaperSize];
  CheckButtons;
end;

procedure TdlgPrinterSetup.chkBinSourceDefaultClick(Sender: TObject);
begin
  if chkBinSourceDefault.Checked then
    prtDef.UseWinDefaults:=prtDef.UseWinDefaults+[DefaultBin]
  else
    prtDef.UseWinDefaults:=prtDef.UseWinDefaults-[DefaultBin];
  CheckButtons;
end;

procedure TdlgPrinterSetup.chkPrintQualityDefaultClick(Sender: TObject);
begin
  if chkPrintQualityDefault.Checked then
    prtDef.UseWinDefaults:=prtDef.UseWinDefaults+[DefaultPrintQuality]
  else
    prtDef.UseWinDefaults:=prtDef.UseWinDefaults-[DefaultPrintQuality];
  CheckButtons;
end;

procedure TdlgPrinterSetup.rbnPortraitClick(Sender: TObject);
begin
  if rbnPortrait.Checked then prtDef.PrinterSettings.Orientation:=Portrait
                         else prtDef.PrinterSettings.Orientation:=Landscape;
  Changed:=true;
  CheckButtons;
end;

procedure TdlgPrinterSetup.FormShow(Sender: TObject);
begin
  edtCopies.Text:=IntToStr(prtDef.PrinterSettings.Copies);
  Changed:=false;
  CheckButtons;
end;

procedure TdlgPrinterSetup.FormCloseQuery(Sender: TObject;
  var CanClose: Boolean);
begin
  CanClose:=btnExit.Enabled;
end;

procedure TdlgPrinterSetup.edtCopiesKeyPress(Sender: TObject;
  var Key: Char);
begin
  if not (Key in [#8,#27,'0'..'9']) then Key:=#0;
end;

procedure TdlgPrinterSetup.edtCopiesChange(Sender: TObject);
begin
  Changed:=true;
  CheckButtons;
end;

end.
